translate.lang.es

Package translate :: Package lang :: Module es |
[hide private]
[frames] | no frames]

# Source Code for Module translate.lang.es

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2007 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # translate is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # translate is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with translate; if not, write to the Free Software
    20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    21
    22  """This module represents Spanish language.
    23  However, as it only has special case code for initial inverted punctuation,
    24  it could also be used for Asturian, Galician, or Catalan.
    25  """
    26
    27  from translate.lang import common
    28  import re
    29
    30 -class es(common.Common):
    31      """This class represents Spanish."""
    32
    33 -    def punctranslate(cls, text):
    34          """Implement some extra features for inverted punctuation.
    35          """
    36          text = super(cls, cls).punctranslate(text)
    37          # If the first sentence ends with ? or !, prepend inverted ¿ or ¡
    38          firstmatch = cls.sentencere.match(text)
    39          if firstmatch == None:
    40              # only one sentence (if any) - use entire string
    41              first = text
    42          else:
    43              first = firstmatch.group()
    44          # remove trailing whitespace
    45          first = first.strip()
    46          # protect against incorrectly handling an empty string
    47          if not first:
    48              return text
    49          if first[-1] == '?':
    50              text = u"¿" + text
    51          elif first[-1] == '!':
    52              text = u"¡" + text
    53          return text
    54      punctranslate = classmethod(punctranslate)
    55